@@ -1,35 +1,37 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2002-2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2002-2004 Marc Maurer (uwog@uwog.net)
- *  
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * For minor contributions see the git repository.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
- 
+
 #include <stdio.h>
 #include <string.h>
 #include "libwpd.h"
 #include "libwpd-stream.h"
 #include "TextDocumentGenerator.h"
 
-namespace {
+namespace
+{
 
 int printUsage()
 {
@@ -64,7 +66,7 @@ int main(int argc, char *argv[])
 	{
 		if (!strcmp(argv[i], "--password"))
 		{
-		    if (i < argc - 1)
+			if (i < argc - 1)
 				password = argv[++i];
 		}
 		else if (!strncmp(argv[i], "--password=", 11))
@@ -75,13 +77,13 @@ int main(int argc, char *argv[])
 			return printVersion();
 		else if (!szInputFile && strncmp(argv[i], "--", 2))
 			szInputFile = argv[i];
-		else 
+		else
 			return printUsage();
 	}
-	
+
 	if (!szInputFile)
 		return printUsage();
-	
+
 	WPXFileStream input(szInputFile);
 
 	WPDConfidence confidence = WPDocument::isFileFormatSupported(&input);
@@ -90,21 +92,21 @@ int main(int argc, char *argv[])
 		fprintf(stderr, "ERROR: Unsupported file format!\n");
 		return 1;
 	}
-	
+
 	if (confidence == WPD_CONFIDENCE_SUPPORTED_ENCRYPTION && !password)
 	{
 		fprintf(stderr, "ERROR: File is password protected! Use \"--password\" option!\n");
 		return 1;
 	}
-	
+
 	if (confidence == WPD_CONFIDENCE_SUPPORTED_ENCRYPTION && password && (WPD_PASSWORD_MATCH_OK != WPDocument::verifyPassword(&input, password)))
 	{
 		fprintf(stderr, "ERROR: The password does not match, or document is not encrypted!\n");
 		return 1;
 	}
-	
+
 	TextDocumentGenerator documentGenerator(isInfo);
- 	WPDResult error = WPDocument::parse(&input, &documentGenerator, password);
+	WPDResult error = WPDocument::parse(&input, &documentGenerator, password);
 
 	if (error == WPD_FILE_ACCESS_ERROR)
 		fprintf(stderr, "ERROR: File Exception!\n");
@@ -122,3 +124,4 @@ int main(int argc, char *argv[])
 
 	return 0;
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
