@@ -1,43 +1,44 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
- *  
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * For minor contributions see the git repository.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by 
+/* "This product is not manufactured, approved, or supported by
  * Corel Corporation or Corel Corporation Limited."
  */
- 
+
 #include "WP42StylesListener.h"
 #include "WPXTable.h"
 #include "WP42FileStructure.h"
 #include "WPXFileStructure.h"
 #include "libwpd_internal.h"
 
-WP42StylesListener::WP42StylesListener(std::list<WPXPageSpan> &pageList, std::vector<WP42SubDocument *> &subDocuments) : 
+WP42StylesListener::WP42StylesListener(std::list<WPXPageSpan> &pageList, std::vector<WP42SubDocument *> &subDocuments) :
 	WP42Listener(),
 	WPXStylesListener(pageList),
 	m_currentPage(),
 	m_nextPage(),
 	m_subDocuments(subDocuments),
-	m_tempMarginLeft(1.0f),
-	m_tempMarginRight(1.0f),
+	m_tempMarginLeft(1.0),
+	m_tempMarginRight(1.0),
 	m_currentPageHasContent(false),
 	m_isSubDocument(false),
 	m_pageListHardPageMark(m_pageList.end())
@@ -45,24 +46,29 @@ WP42StylesListener::WP42StylesListener(std::list<WPXPageSpan> &pageList, std::ve
 }
 
 void WP42StylesListener::endDocument()
-{	
+{
 	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
 }
 
-void WP42StylesListener::insertBreak(const uint8_t breakType)
+void WP42StylesListener::endSubDocument()
+{
+	insertBreak(WPX_SOFT_PAGE_BREAK); // pretend we just had a soft page break (for the last page)
+}
+
+void WP42StylesListener::insertBreak(uint8_t breakType)
 {
 	if (m_isSubDocument)
 		return;
 
 	if (!isUndoOn())
-	{	
+	{
 		WPXTableList tableList;
-		switch (breakType) 
+		switch (breakType)
 		{
 		case WPX_PAGE_BREAK:
 		case WPX_SOFT_PAGE_BREAK:
 			if ((m_pageList.size() > 0) && (m_currentPage==m_pageList.back())
-				&& (m_pageListHardPageMark != m_pageList.end()))
+			        && (m_pageListHardPageMark != m_pageList.end()))
 			{
 				m_pageList.back().setPageSpan(m_pageList.back().getPageSpan() + 1);
 			}
@@ -71,30 +77,32 @@ void WP42StylesListener::insertBreak(const uint8_t breakType)
 				m_pageList.push_back(WPXPageSpan(m_currentPage));
 				if (m_pageListHardPageMark == m_pageList.end())
 				{
-					m_pageListHardPageMark--;
+					--m_pageListHardPageMark;
 				}
 			}
-			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0f, 0.0f);
+			m_currentPage = WPXPageSpan(m_pageList.back(), 0.0, 0.0);
 			m_currentPage.setPageSpan(1);
 
 			for(std::vector<WPXHeaderFooter>::const_iterator HFiter = (m_nextPage.getHeaderFooterList()).begin();
-				HFiter != (m_nextPage.getHeaderFooterList()).end(); HFiter++)
+			        HFiter != (m_nextPage.getHeaderFooterList()).end(); ++HFiter)
 			{
 				if ((*HFiter).getOccurence() != NEVER)
 				{
 					m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-						(*HFiter).getOccurence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
-					_handleSubDocument((*HFiter).getSubDocument(), true, (*HFiter).getTableList());
+					                              (*HFiter).getOccurence(), (*HFiter).getSubDocument(), (*HFiter).getTableList());
+					_handleSubDocument((*HFiter).getSubDocument(), WPX_SUBDOCUMENT_HEADER_FOOTER, (*HFiter).getTableList());
 				}
 				else
 				{
 					m_currentPage.setHeaderFooter((*HFiter).getType(), (*HFiter).getInternalType(),
-						(*HFiter).getOccurence(), 0, (*HFiter).getTableList());
-				}	
+					                              (*HFiter).getOccurence(), 0, (*HFiter).getTableList());
+				}
 			}
 			m_nextPage = WPXPageSpan();
 			m_currentPageHasContent = false;
 			break;
+		default:
+			break;
 		}
 		if (breakType == WPX_PAGE_BREAK)
 		{
@@ -106,7 +114,7 @@ void WP42StylesListener::insertBreak(const uint8_t breakType)
 }
 
 
-void WP42StylesListener::headerFooterGroup(const uint8_t headerFooterDefinition, WP42SubDocument *subDocument)
+void WP42StylesListener::headerFooterGroup(uint8_t headerFooterDefinition, WP42SubDocument *subDocument)
 {
 	if (subDocument)
 		m_subDocuments.push_back(subDocument);
@@ -120,8 +128,8 @@ void WP42StylesListener::headerFooterGroup(const uint8_t headerFooterDefinition,
 
 		uint8_t occurenceBits = ((headerFooterDefinition & 0xFC) >> 2);
 
-		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurenceBits: %i)\n", 
-			       headerFooterType, occurenceBits));
+		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurenceBits: %i)\n",
+		               headerFooterType, occurenceBits));
 
 		WPXHeaderFooterOccurence wpxOccurence;
 
@@ -143,16 +151,16 @@ void WP42StylesListener::headerFooterGroup(const uint8_t headerFooterDefinition,
 			if (wpxOccurence != NEVER)
 			{
 				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, subDocument, tableList);
-				_handleSubDocument(subDocument, true, tableList);
+				_handleSubDocument(subDocument, WPX_SUBDOCUMENT_HEADER_FOOTER, tableList);
 			}
 			else
 				m_currentPage.setHeaderFooter(wpxType, headerFooterType, wpxOccurence, 0, tableList);
 		}
 		m_currentPageHasContent = tempCurrentPageHasContent;
 	}
-}	
+}
 
-void WP42StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
+void WP42StylesListener::suppressPageCharacteristics(uint8_t suppressCode)
 {
 	if (!isUndoOn())
 	{
@@ -179,14 +187,14 @@ void WP42StylesListener::suppressPageCharacteristics(const uint8_t suppressCode)
 	}
 }
 
-void WP42StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, const bool isHeaderFooter,
-						WPXTableList /* tableList */, int /* nextTableIndice */)
+void WP42StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType,
+        WPXTableList /* tableList */, int /* nextTableIndice */)
 {
-	if (!isUndoOn()) 
+	if (!isUndoOn())
 	{
 		bool oldIsSubDocument = m_isSubDocument;
 		m_isSubDocument = true;
-		if (isHeaderFooter) 
+		if (subDocumentType == WPX_SUBDOCUMENT_HEADER_FOOTER)
 		{
 			bool oldCurrentPageHasContent = m_currentPageHasContent;
 
@@ -203,3 +211,4 @@ void WP42StylesListener::_handleSubDocument(const WPXSubDocument *subDocument, c
 		m_isSubDocument = oldIsSubDocument;
 	}
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
