@@ -1,19 +1,20 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -40,7 +41,7 @@
 typedef struct _WPXTableDefinition WPXTableDefinition;
 struct _WPXTableDefinition
 {
-	_WPXTableDefinition() : m_positionBits(0), m_leftOffset(0.0), m_columns(), m_columnsProperties() {};
+	_WPXTableDefinition() : m_positionBits(0), m_leftOffset(0.0), m_columns(), m_columnsProperties() {}
 	uint8_t m_positionBits;
 	double m_leftOffset;
 	std::vector < WPXColumnDefinition > m_columns;
@@ -91,13 +92,13 @@ struct _WPXContentParsingState
 	bool m_isRowWithoutCell;
 	uint32_t m_cellAttributeBits;
 	uint8_t m_paragraphJustificationBeforeTable;
-	
+
 	unsigned m_currentPage;
-	int m_numPagesRemainingInSpan;
-	int m_currentPageNumber;
+	unsigned m_numPagesRemainingInSpan;
+	unsigned m_currentPageNumber;
 
 	bool m_sectionAttributesChanged;
-	int m_numColumns;
+	unsigned m_numColumns;
 	std::vector < WPXColumnDefinition > m_textColumns;
 	bool m_isTextColumnWithoutParagraph;
 
@@ -116,11 +117,11 @@ struct _WPXContentParsingState
 	double m_leftMarginByPageMarginChange;  // part of the margin due to the PAGE margin change
 	double m_rightMarginByPageMarginChange; // inside a page that already has content.
 	double m_sectionMarginLeft;  // In multicolumn sections, the above two will be rather interpreted
-	double m_sectionMarginRight; // as section margin change 
+	double m_sectionMarginRight; // as section margin change
 	double m_leftMarginByParagraphMarginChange;  // part of the margin due to the PARAGRAPH
 	double m_rightMarginByParagraphMarginChange; // margin change (in WP6)
 	double m_leftMarginByTabs;  // part of the margin due to the LEFT or LEFT/RIGHT Indent; the
-	double m_rightMarginByTabs; // only part of the margin that is reset at the end of a paragraph	
+	double m_rightMarginByTabs; // only part of the margin that is reset at the end of a paragraph
 
 	double m_listReferencePosition; // position from the left page margin of the list number/bullet
 	double m_listBeginPosition; // position from the left page margin of the beginning of the list
@@ -130,8 +131,8 @@ struct _WPXContentParsingState
 	double m_textIndentByTabs; // part of the indent due to the "Back Tab" or "Left Tab"
 
 	uint8_t m_currentListLevel;
-	
-	uint16_t m_alignmentCharacter;
+
+	uint32_t m_alignmentCharacter;
 	std::vector<WPXTabStop> m_tabStops;
 	bool m_isTabPositionRelative;
 
@@ -142,8 +143,8 @@ struct _WPXContentParsingState
 	WPXSubDocumentType m_subDocumentType;
 
 private:
-	_WPXContentParsingState(const _WPXContentParsingState&);
-	_WPXContentParsingState& operator=(const _WPXContentParsingState&);
+	_WPXContentParsingState(const _WPXContentParsingState &);
+	_WPXContentParsingState &operator=(const _WPXContentParsingState &);
 };
 
 class WPXContentListener : public WPXListener
@@ -156,16 +157,16 @@ protected:
 	void startSubDocument();
 	void endDocument();
 	void endSubDocument();
-	void handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice);
+	void handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, unsigned nextTableIndice);
 	void insertBreak(const uint8_t breakType);
 	void lineSpacingChange(const double lineSpacing);
 	void justificationChange(const uint8_t justification);
 
 	WPXContentParsingState *m_ps; // parse state
-	WPXDocumentInterface * m_documentInterface;
+	WPXDocumentInterface *m_documentInterface;
 	WPXPropertyList m_metaData;
 
-	virtual void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice) = 0;
+	virtual void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, unsigned nextTableIndice) = 0;
 	virtual void _flushText() = 0;
 	virtual void _changeList() = 0;
 
@@ -192,32 +193,33 @@ protected:
 	void _closeTable();
 	void _openTableRow(const double height, const bool isMinimumHeight, const bool isHeaderRow);
 	void _closeTableRow();
-	void _openTableCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits, 
-				const RGBSColor * cellFgColor, const RGBSColor * cellBgColor,
-				const RGBSColor * cellBorderColor,
-				const WPXVerticalAlignment cellVerticalAlignment);
+	void _openTableCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits,
+	                    const RGBSColor *cellFgColor, const RGBSColor *cellBgColor,
+	                    const RGBSColor *cellBorderColor,
+	                    const WPXVerticalAlignment cellVerticalAlignment);
 	void _closeTableCell();
 
 	double _movePositionToFirstColumn(double position);
 
 	double _getNextTabStop() const;
 	double _getPreviousTabStop() const;
-	
-        void _insertText(const WPXString &textBuffer);
+
+	void _insertText(const WPXString &textBuffer);
 
 	void _insertBreakIfNecessary(WPXPropertyList &propList);
-	
+
 	void _insertPageNumberParagraph(WPXPageNumberPosition position, WPXNumberingType type, WPXString fontName, double fontSize);
 
 	uint32_t _mapNonUnicodeCharacter(uint32_t character);
-	
+
 private:
-	WPXContentListener(const WPXContentListener&);
-	WPXContentListener& operator=(const WPXContentListener&);
-	WPXString _colorToString(const RGBSColor * color);
+	WPXContentListener(const WPXContentListener &);
+	WPXContentListener &operator=(const WPXContentListener &);
+	WPXString _colorToString(const RGBSColor *color);
 	WPXString _mergeColorsToString(const RGBSColor *fgColor, const RGBSColor *bgColor);
 	uint32_t _mapSymbolFontCharacter(uint32_t character);
 	uint32_t _mapDingbatsFontCharacter(uint32_t character);
 };
 
 #endif /* WPXCONTENTLISTENER_H */
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
