@@ -1,22 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2004 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2005 Net Integration Technologies (http://www.net-itech.com)
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -28,6 +28,7 @@
 #include "WPXPropertyList.h"
 #include <map>
 #include <string>
+#include <utility>
 
 class WPXMapImpl
 {
@@ -39,6 +40,11 @@ public:
 	void remove(const char *name);
 	void clear();
 
+private:
+	// disable copy construction and assignment
+	WPXMapImpl(const WPXMapImpl &other);
+	WPXMapImpl &operator=(const WPXMapImpl &other);
+
 private:
 	mutable std::map<std::string, WPXProperty *> m_map;
 
@@ -49,7 +55,7 @@ WPXMapImpl::~WPXMapImpl()
 {
 	for (std::map<std::string, WPXProperty *>::iterator iter = m_map.begin();
 	        iter != m_map.end();
-	        iter++)
+	        ++iter)
 	{
 		delete iter->second;
 	}
@@ -93,7 +99,7 @@ void WPXMapImpl::clear()
 {
 	for (std::map<std::string, WPXProperty *>::iterator iter = m_map.begin();
 	        iter != m_map.end();
-	        iter++)
+	        ++iter)
 	{
 		delete iter->second;
 	}
@@ -167,12 +173,8 @@ void WPXPropertyList::remove(const char *name)
 
 const WPXPropertyList &WPXPropertyList::operator=(const WPXPropertyList &propList)
 {
-	clear();
-	WPXPropertyList::Iter i(propList);
-	for (i.rewind(); i.next(); )
-	{
-		insert(i.key(), i()->clone());
-	}
+	WPXPropertyList tmp(propList);
+	std::swap(m_mapImpl, tmp.m_mapImpl);
 	return *this;
 }
 
@@ -186,6 +188,13 @@ void WPXPropertyList::clear()
 	m_mapImpl->clear();
 }
 
+#if 0
+void WPXPropertyList::swap(WPXPropertyList &other)
+{
+	std::swap(m_mapImpl, other.m_mapImpl);
+}
+#endif
+
 class WPXMapIterImpl
 {
 public:
@@ -199,7 +208,7 @@ public:
 private:
 	bool m_imaginaryFirst;
 	std::map<std::string, WPXProperty *>::iterator m_iter;
-	std::map<std::string, WPXProperty *> * m_map;
+	std::map<std::string, WPXProperty *> *m_map;
 };
 
 
@@ -220,7 +229,7 @@ void WPXMapIterImpl::rewind()
 bool WPXMapIterImpl::next()
 {
 	if (!m_imaginaryFirst)
-		m_iter++;
+		++m_iter;
 	if (m_iter==m_map->end())
 		return false;
 	m_imaginaryFirst = false;
