@@ -1,20 +1,20 @@
-/* libwps
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2006 Andrew Ziem
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * For minor contributions see the git repository.
  *
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  */
 
 #include <iostream>
@@ -38,16 +38,16 @@
 
 class Test : public CPPUNIT_NS::TestFixture
 {
-  CPPUNIT_TEST_SUITE(Test);
-  CPPUNIT_TEST(testStream);
-  CPPUNIT_TEST_SUITE_END();
+	CPPUNIT_TEST_SUITE(Test);
+	CPPUNIT_TEST(testStream);
+	CPPUNIT_TEST_SUITE_END();
 
 public:
-  void setUp(void);
-  void tearDown(void);
+	void setUp(void);
+	void tearDown(void);
 
 protected:
-  void testStream(void);
+	void testStream(void);
 
 };
 
@@ -65,18 +65,17 @@ void Test::tearDown(void)
 }
 
 void Test::testStream(void)
-{ 
-	WPXInputStream* input = 0;
+{
 	unsigned long numBytesRead;
 	unsigned long u32;
 
-	/********************** 
+	/**********************
 	 * Test WPXFileStream *
 	 **********************/
-	input = new WPXFileStream(TMP_FILENAME);
+	WPXInputStream *input = new WPXFileStream(TMP_FILENAME);
 
 	CPPUNIT_ASSERT_EQUAL ( false, input->isOLEStream() );
-	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream*) NULL, input->getDocumentOLEStream("foo") );
+	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream *) NULL, input->getDocumentOLEStream("foo") );
 
 	// test read()
 	input->seek(0, WPX_SEEK_SET);
@@ -129,20 +128,20 @@ void Test::testStream(void)
 
 	input->seek(8, WPX_SEEK_SET);
 	CPPUNIT_ASSERT_EQUAL ( true, input->atEOS() );
-	
+
 	input->seek(10000, WPX_SEEK_SET);
 	CPPUNIT_ASSERT( 10000 != input->tell() );
 	CPPUNIT_ASSERT( input->atEOS() );
 
 	delete input;
 
-	/************************ 
+	/************************
 	 * Test WPXStringStream *
 	 ************************/
 	input = new WPXStringStream((const unsigned char *)"\1\2\3\4\0\5\6\7", 8);
 
 	CPPUNIT_ASSERT_EQUAL ( false, input->isOLEStream() );
-	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream*) NULL, input->getDocumentOLEStream("foo") );
+	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream *) NULL, input->getDocumentOLEStream("foo") );
 
 	// test read()
 	input->seek(0, WPX_SEEK_SET);
@@ -195,7 +194,7 @@ void Test::testStream(void)
 
 	input->seek(8, WPX_SEEK_SET);
 	CPPUNIT_ASSERT_EQUAL ( true, input->atEOS() );
-	
+
 	input->seek(10000, WPX_SEEK_SET);
 	CPPUNIT_ASSERT( 10000 != input->tell() );
 	CPPUNIT_ASSERT( input->atEOS() );
@@ -203,13 +202,13 @@ void Test::testStream(void)
 	delete input;
 
 
-	/************************ 
+	/************************
 	 * Test WPXMemoryInputStream *
 	 ************************/
 	input = new WPXMemoryInputStream((uint8_t *)("\1\2\3\4\0\5\6\7"), 8);
 
 	CPPUNIT_ASSERT_EQUAL ( false, input->isOLEStream() );
-	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream*) NULL, input->getDocumentOLEStream("foo") );
+	CPPUNIT_ASSERT_EQUAL ( (WPXInputStream *) NULL, input->getDocumentOLEStream("foo") );
 
 	// test read()
 	input->seek(0, WPX_SEEK_SET);
@@ -262,7 +261,7 @@ void Test::testStream(void)
 
 	input->seek(8, WPX_SEEK_SET);
 	CPPUNIT_ASSERT_EQUAL ( true, input->atEOS() );
-	
+
 	input->seek(10000, WPX_SEEK_SET);
 	CPPUNIT_ASSERT( 10000 != input->tell() );
 	CPPUNIT_ASSERT( input->atEOS() );
@@ -274,18 +273,18 @@ void Test::testStream(void)
 
 CPPUNIT_TEST_SUITE_REGISTRATION(Test);
 
-int main( int argc, char **argv )
+int main()
 {
 	// Create the event manager and test controller
 	CPPUNIT_NS::TestResult controller;
 
 	// Add a listener that colllects test result
 	CPPUNIT_NS::TestResultCollector result;
-	controller.addListener( &result );        
+	controller.addListener( &result );
 
 	// Add a listener that print dots as test run.
 	CPPUNIT_NS::BriefTestProgressListener progress;
-	controller.addListener( &progress );      
+	controller.addListener( &progress );
 
 	// Add the top suite to the test runner
 	CPPUNIT_NS::TestRunner runner;
@@ -299,3 +298,4 @@ int main( int argc, char **argv )
 	// return status code
 	return result.wasSuccessful() ? 0 : 1;
 }
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
